@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004-2010 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2004-2011 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -20,13 +20,13 @@
  */
 /*
   File:      tiffcomposite.cpp
-  Version:   $Rev: 2344 $
+  Version:   $Rev: 2455 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   11-Apr-06, ahu: created
  */
 // *****************************************************************************
 #include "rcsid_int.hpp"
-EXIV2_RCSID("@(#) $Id: tiffcomposite.cpp 2344 2010-09-10 14:02:09Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: tiffcomposite.cpp 2455 2011-02-13 14:39:15Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -143,7 +143,8 @@ namespace Exiv2 {
           setSize_(0),
           origData_(0),
           origSize_(0),
-          pRoot_(0)
+          pRoot_(0),
+          decoded_(false)
     {
         assert(arrayCfg != 0);
     }
@@ -162,7 +163,8 @@ namespace Exiv2 {
           setSize_(setSize),
           origData_(0),
           origSize_(0),
-          pRoot_(0)
+          pRoot_(0),
+          decoded_(false)
     {
         // We'll figure out the correct cfg later
         assert(cfgSelFct != 0);
@@ -282,7 +284,8 @@ namespace Exiv2 {
           setSize_(rhs.setSize_),
           origData_(rhs.origData_),
           origSize_(rhs.origSize_),
-          pRoot_(rhs.pRoot_)
+          pRoot_(rhs.pRoot_),
+          decoded_(false)
     {
     }
 
@@ -841,6 +844,7 @@ namespace Exiv2 {
     {
         TiffComponent* tc = tiffComponent.release();
         elements_.push_back(tc);
+        setDecoded(true);
         return tc;
     } // TiffBinaryArray::doAddChild
 
@@ -1036,7 +1040,7 @@ namespace Exiv2 {
 
     uint32_t TiffBinaryArray::doCount() const
     {
-        if (cfg() == 0) return TiffEntryBase::doCount();
+        if (cfg() == 0 || !decoded()) return TiffEntryBase::doCount();
 
         if (elements_.empty()) return 0;
 
@@ -1290,7 +1294,7 @@ namespace Exiv2 {
         // For makernotes, write TIFF image data to the data area
         if (group() > mnId) o2 = offset + dataIdx;
 #ifdef DEBUG
-        std::cerr << "TiffImageEntry, Directory " << ifdItem(group())
+        std::cerr << "TiffImageEntry, Directory " << groupName(group())
                   << ", entry 0x" << std::setw(4)
                   << std::setfill('0') << std::hex << tag() << std::dec
                   << ": Writing offset " << o2 << "\n";
@@ -1366,12 +1370,12 @@ namespace Exiv2 {
                                       uint32_t  dataIdx,
                                       uint32_t& imageIdx)
     {
-        if (cfg() == 0) return TiffEntryBase::doWrite(ioWrapper,
-                                                      byteOrder,
-                                                      offset,
-                                                      valueIdx,
-                                                      dataIdx,
-                                                      imageIdx);
+        if (cfg() == 0 || !decoded()) return TiffEntryBase::doWrite(ioWrapper,
+                                                                    byteOrder,
+                                                                    offset,
+                                                                    valueIdx,
+                                                                    dataIdx,
+                                                                    imageIdx);
         if (cfg()->byteOrder_ != invalidByteOrder) byteOrder = cfg()->byteOrder_;
         // Tags must be sorted in ascending order
         std::sort(elements_.begin(), elements_.end(), cmpTagLt);
@@ -1586,7 +1590,7 @@ namespace Exiv2 {
         uint32_t len = pValue()->sizeDataArea();
         if (len > 0) {
 #ifdef DEBUG
-            std::cerr << "TiffImageEntry, Directory " << ifdItem(group())
+            std::cerr << "TiffImageEntry, Directory " << groupName(group())
                       << ", entry 0x" << std::setw(4)
                       << std::setfill('0') << std::hex << tag() << std::dec
                       << ": Writing data area, size = " << len;
@@ -1599,7 +1603,7 @@ namespace Exiv2 {
         }
         else {
 #ifdef DEBUG
-            std::cerr << "TiffImageEntry, Directory " << ifdItem(group())
+            std::cerr << "TiffImageEntry, Directory " << groupName(group())
                       << ", entry 0x" << std::setw(4)
                       << std::setfill('0') << std::hex << tag() << std::dec
                       << ": Writing " << strips_.size() << " strips";
@@ -1681,7 +1685,7 @@ namespace Exiv2 {
 
     uint32_t TiffBinaryArray::doSize() const
     {
-        if (cfg() == 0) return TiffEntryBase::doSize();
+        if (cfg() == 0 || !decoded()) return TiffEntryBase::doSize();
 
         if (elements_.empty()) return 0;
 
